"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.KeycloakStrategy = void 0;
const remix_auth_oauth2_1 = require("remix-auth-oauth2");
class KeycloakStrategy extends remix_auth_oauth2_1.OAuth2Strategy {
    // We receive our custom options and our verify callback
    constructor(options, 
    // Here we type the verify callback as a StrategyVerifyCallback receiving
    // the User type and the OAuth2StrategyVerifyParams with the Auth0Profile
    // and the Auth0ExtraParams
    // This way, when using the strategy the verify function will receive as
    // params an object with accessToken, refreshToken, extraParams and profile.
    // The latest two matching the types of Auth0Profile and Auth0ExtraParams.
    verify) {
        // And we pass the options to the super constructor using our own options
        // to generate them, this was we can ask less configuration to the developer
        // using our strategy
        const host = `${options.useSSL ? "https" : "http"}://${options.domain}`;
        super({
            authorizationURL: `${host}/realms/${options.realm}/protocol/openid-connect/auth`,
            tokenURL: `${host}/realms/${options.realm}/protocol/openid-connect/token`,
            clientID: options.clientID,
            clientSecret: options.clientSecret,
            callbackURL: options.callbackURL,
        }, verify);
        // The OAuth2Strategy already has a name but we override it to be specific of
        // the service we are using
        this.name = "keycloak";
        this.userInfoURL = `${host}/realms/${options.realm}/protocol/openid-connect/userinfo`;
        this.scope = options.scope || "openid profile email";
    }
    // We override the protected authorizationParams method to return a new
    // URLSearchParams with custom params we want to send to the authorizationURL.
    // Here we add the scope so Auth0 can use it, you can pass any extra param
    // you need to send to the authorizationURL here base on your provider.
    authorizationParams() {
        const urlSearchParams = {
            scope: this.scope,
        };
        return new URLSearchParams(urlSearchParams);
    }
    // We also override how to use the accessToken to get the profile of the user.
    // Here we fetch a Auth0 specific URL, get the profile data, and build the
    // object based on the Auth0Profile interface.
    async userProfile(accessToken) {
        let response = await fetch(this.userInfoURL, {
            headers: { Authorization: `Bearer ${accessToken}` },
        });
        let data = await response.json();
        let profile = {
            provider: "keycloak",
            displayName: data.name,
            id: data.sub,
            name: {
                familyName: data.family_name,
                givenName: data.given_name,
            },
            emails: [{ value: data.email }],
            _json: data,
        };
        return profile;
    }
}
exports.KeycloakStrategy = KeycloakStrategy;
